@@ -56,7 +56,7 @@ class Lib3:
 				while (lines[i] != "---\n"):
 					if ("|" not in lines[i]):
 						entry[last] = entry[last] + "\n" + lines[i].strip()
-					else:	
+					else:
 						tokens = lines[i].split("|")
 						entry[tokens[0]] = tokens[1].strip()
 						last = tokens[0]
@@ -91,12 +91,12 @@ class Lib3:
 		sites = data+os.sep+"sites"
 		dirs = os.listdir(sites)
 		for dir in dirs:
-			try: 
+			try:
 				f = open(sites+os.sep+dir+os.sep+file)
 				list = f.read()
 				f.close()
-				if (list.find(key) != -1):
-					return list.split("\n")
+				if key in list:
+					return list.splitlines()
 			except: # handles non-e-zine subsites
 				continue
 		return []
@@ -216,8 +216,8 @@ class Lib3:
 			for file in files:
 				if (file != ""):
 					f.write(file+"\n")
-			f.close()	
-		return 
+			f.close()
+		return
 
 	def strip_html(self, line):
 		length = len(line)
@@ -228,7 +228,7 @@ class Lib3:
 			if (line[i] == '<'):
 				tag = 1
 			if not (tag):
-				newln.append(line[i])				
+				newln.append(line[i])
 			if (line[i] == '>'):
 				tag = 0
 				newln.append(" ")
@@ -262,7 +262,7 @@ class Lib3:
 			ks = d.keys()
 			for k in ks:
 				f.write(k+"|"+d[k]+"\n")
-			f.write("---\n")	
+			f.write("---\n")
 			size += int(d["sum"])
 			if (size > self.FILE_MAX): break
 		f.close()
